Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(307)

Unified Diff: third_party/WebKit/Source/core/editing/EditingStrategy.h

Issue 1675163002: Rename ComposedTree to FlatTree (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: wip Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/editing/EditingStrategy.h
diff --git a/third_party/WebKit/Source/core/editing/EditingStrategy.h b/third_party/WebKit/Source/core/editing/EditingStrategy.h
index c6256ea75c85a29d0a6b94a9a77742cd8f8a6e32..3e276d68abe701e74b2656f56eadfe763d0a2f20 100644
--- a/third_party/WebKit/Source/core/editing/EditingStrategy.h
+++ b/third_party/WebKit/Source/core/editing/EditingStrategy.h
@@ -7,7 +7,7 @@
#include "core/CoreExport.h"
#include "core/dom/NodeTraversal.h"
-#include "core/dom/shadow/ComposedTreeTraversal.h"
+#include "core/dom/shadow/FlatTreeTraversal.h"
#include "wtf/Allocator.h"
namespace blink {
@@ -39,12 +39,12 @@ public:
};
extern template class CORE_EXTERN_TEMPLATE_EXPORT EditingAlgorithm<NodeTraversal>;
-extern template class CORE_EXTERN_TEMPLATE_EXPORT EditingAlgorithm<ComposedTreeTraversal>;
+extern template class CORE_EXTERN_TEMPLATE_EXPORT EditingAlgorithm<FlatTreeTraversal>;
// DOM tree version of editing algorithm
using EditingStrategy = EditingAlgorithm<NodeTraversal>;
-// Composed tree version of editing algorithm
-using EditingInComposedTreeStrategy = EditingAlgorithm<ComposedTreeTraversal>;
+// Flat tree version of editing algorithm
+using EditingInFlatTreeStrategy = EditingAlgorithm<FlatTreeTraversal>;
} // namespace blink

Powered by Google App Engine
This is Rietveld 408576698